This will almost certainly return the same result as typeof(x). However,
the author would be interested to know if it doesn't!
Value
The name of the fundamental vector type of that x is representing,
as a character scalar. For example "integer" or "character".