This checks if x is an instance of an ALTREP class. Notably it doesn't
check if x is an ALTREP class
(ie the return value from alt_class()), which is more difficult to
achieve.
This checks if x is an instance of an ALTREP class. Notably it doesn't
check if x is an ALTREP class
(ie the return value from alt_class()), which is more difficult to
achieve.