Makes a memory-mapped vector
Arguments
- path
Path to an existing file, or a file to write to if
datais provided- data
A double or integer vector to write to
path, orNULLto only read from it.- type
Either "double" or "integer", indicating the data type to read from disk. If not provided, it will be assumed to be the type of
data.